@@ -1,8 +1,8 @@
 #########################################################################
-# - Net::UCP 0.28 - 
+# - Net::UCP 0.29 - 
 # 
-# Version : 0.28
-# Date    : 18/10/2007
+# Version : 0.29
+# Date    : 31/10/2007
 #
 # Library based on EMI - UCP INTERFACE Specification 
 # Version 3.5 of December 1999 
@@ -27,12 +27,13 @@ use Time::HiRes qw(setitimer ITIMER_REAL);
 
 require Exporter;
 
-our @ISA = qw(Exporter);
+use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
 
-our @EXPORT = qw();
-our @EXPORT_OK = ();
+@ISA = qw(Exporter);
+@EXPORT = qw();
+@EXPORT_OK = ();
 
-our $VERSION = '0.27';
+$VERSION = '0.29';
 
 $VERSION = eval $VERSION; 
 
@@ -2033,18 +2034,6 @@ use constant NACK=>'N';
 
 use constant DEBUG=>0;
 
-use vars qw(%accent_table);
-
-#IA5 by vi
-%accent_table = (
-                 '05' => '0xe8',
-                 '04' => '0xe9',
-                 '06' => '0xf9',
-                 '07' => '0xec',
-                 '08' => '0xf2',
-                 '7F' => '0xe0'
-                 );
-
 sub new {
     my$self={};
     bless($self,shift())->_init(@_);
@@ -2117,11 +2106,7 @@ sub ia5_decode {
     
     while (length($msg)) {
 	($tmp,$msg) = ($msg =~ /(..)(.*)/);
-	if ($accent_table{$tmp}) {
-	    $out .= sprintf("%s", chr(hex($accent_table{$tmp})));
-	} else {
-	    $out .= sprintf("%s", chr(hex($tmp)));
-	}
+	$out .= sprintf("%s", chr(hex($tmp)));
     }
     
     return ($out);
@@ -2245,11 +2230,9 @@ such service provider.) If you want to help my project send me info about some S
 A Net::UCP object must be created with the new() constructor.
 Once this has been done, all commands are accessed via method calls on the object.
 
-*****
 If you have a good know-how about EMI/UCP or if you have patience to read 
 specification you can use this module in raw mode. 
 See RAW MODE for more informations.
-*****
 
 =head1 EXAMPLE
    
@@ -2562,11 +2545,12 @@ your application will wait B<indefinitively>.
 
 use it as send_sms() but you are able to send messages with text length bigger then 160 characters. 
 
-$emi->send_sms_multipart(
-			 RECIPIENT      => '+393291212121',
-			 MESSAGE_TEXT   => 'Message text with more then 160 characters',
-			 SENDER_TEXT    => 'Marco',
-			 );
+    $emi->send_sms_multipart(
+			     RECIPIENT      => '+393291212121',
+			     MESSAGE_TEXT   => 'Message text with more then 160 characters',
+			     SENDER_TEXT    => 'Marco',
+			     );
+
 
 ( Don't use it in a production environment. Please test it and contact me for improvment and bugs )
 
@@ -2871,9 +2855,9 @@ another example.. op 02
 
 This module version support second release of SMSCfAKE, with this feature you are able to start a simple smsc 
 that receive messages from any client. It parses and prints out UCP messages. 
-Using C<action> parameter is possible to add a call back that SMSCfAKE will call when it'll receive an UCP 
+Using C<action> parameter is possible to add a call back that SMSCfAKE will call when it will receive an UCP 
 string. In order to improve the possibility to use it as an application tester i've added another parameter :
-C<sending> to add another call back that it'll call after first call back C<action>
+C<sending> to add another call back that it will call after first call back C<action>
 
 Simple Interaction Diagram :
 
@@ -2900,7 +2884,7 @@ Is possible to create a simple Fake SMSC through method reported below.
 
 =item create_smsc_fake()
 
-It accepts 5 optional parameters :  host, port, listen, output, action
+It accepts 8 optional parameters :  host, port, listen, output, action, sending, reading_mode, max_len
 
     1) host : set smsc address (default are 127.0.0.1)
     2) port : set smsc port (default are 6666)
@@ -2911,7 +2895,7 @@ It accepts 5 optional parameters :  host, port, listen, output, action
                 It could be get back a UCP string response into a scalar value. This value will be printed 
                 get back to the client.
                 Without this parameter smsc fake parse UCP string and will print it on stdout.
-    6) sending (another internal subroutine useful to send another UCP string to client)
+    6) sending      : (another internal subroutine useful to send another UCP string to client)
     7) reading_mode : it can be equal to 0 to receive UCP string with new line at the end 
                       it can be equal to 1 to receive UCP string without new line at the end
     8) max_len      : max byte length of ucp string receive in reading_mode 1 default value 1024 (1Kb)
